from django import forms
from easy_select2.widgets import Select2

from handytools.settings import (TEXT_PHRASE_LANGUAGES,
                                 TEXT_PHRASE_MODEL_PHRASE_TYPES,)
from handytools.textphrase.models import TextPhrase


class TextPhraseForm(forms.ModelForm):
    phrase_type = forms.ChoiceField(
        choices=TEXT_PHRASE_MODEL_PHRASE_TYPES, widget=Select2())
    language = forms.ChoiceField(
        choices=TEXT_PHRASE_LANGUAGES(), widget=Select2())

    class Meta:
        model = TextPhrase
        fields = '__all__'



from django.apps import AppConfig
from django.utils.translation import ugettext_lazy as _


class TextPhraseConfig(AppConfig):
    name = 'handytools.textphrase'
    verbose_name = _('Text Phrase App')



from django import template

register = template.Library()


@register.inclusion_tag("handyutils/google-analytics.html")
def google_analytic(api_key=None):
    if not api_key:
        raise Exception("google api key is required.")
    return {
        "api_key": api_key
    }



from django.apps import AppConfig
from django.utils.translation import ugettext_lazy as _


class HandyUtilsConfig(AppConfig):
    name = 'handytools.handyutils'
    verbose_name = _('Handy Utils App')



from django import forms
from easy_select2.widgets import Select2

from handytools.settings import TEXT_IMAGE_PHRASE_MODEL_POSITIONS
from handytools.textimagephrase.models import TextImagePhrase


class TextImagePhraseForm(forms.ModelForm):
    position = forms.ChoiceField(
        choices=TEXT_IMAGE_PHRASE_MODEL_POSITIONS, widget=Select2())

    class Meta:
        model = TextImagePhrase
        fields = '__all__'




from ckeditor_uploader.fields import RichTextUploadingField
from django.db import models
from django.utils.translation import gettext_lazy as _
from filer.fields.image import FilerImageField


class TextImagePhraseAbstractModel(models.Model):
    """
    we use those fields in other abstract models.
    """
    title = models.CharField(
        max_length=255,
        verbose_name=_('Title')
    )
    image = FilerImageField(
        verbose_name=_('Image'),
        on_delete=models.CASCADE
    )
    text = RichTextUploadingField(
        verbose_name=_('Text')
    )
    position = models.CharField(max_length=255, verbose_name=_('Location'))

    def __str__(self):
        return self.title

    def __unicode__(self):
        return u'%s' % self.title

    class Meta:
        abstract = True
        verbose_name = _('Text & Image Phrase')
        verbose_name_plural = _('Text & Image Phrases')


class TextImagePhrase(TextImagePhraseAbstractModel):
    """
    this model will implement TextImagePhraseAbstractModel.
    if you don't like style or fields you can import
    TextImagePhraseAbstractModel and overwrite this model,
    and then delete TextImagePhraseModel from settings.py
    """



from django.contrib import admin

from .forms import TextImagePhraseForm
from .models import TextImagePhrase


class TextImagePhrasesAdminPanel(admin.ModelAdmin):
    list_display = ['title', 'position']
    search_fields = ['title', 'text', 'position']
    form = TextImagePhraseForm


admin.site.register(TextImagePhrase, TextImagePhrasesAdminPanel)



from django import template

register = template.Library()


@register.simple_tag(takes_context=True)
def single_text_phrase(context, phrase_type=None, language=None):
    """
    for using this template tag you must
    enable one of the text_phrase context_processors.
    this templatetag will return the first text phrase object,
    if there is more then one object.
    if you want single text phrase in special language set the language arg.
    """
    phrases = context.get('text_phrases', None)
    if not phrases:
        raise Exception(
            "for using single_text_phrase templatetag, "
            "Please Enable one of the Text Phrase Context Processors"
        )
    if not language:
        phrase = phrases.filter(phrase_type=phrase_type)
        return phrase.first()
    phrase = phrases.filter(phrase_type=phrase_type, language=language)
    return phrase.first()


@register.simple_tag(takes_context=True)
def multi_text_phrase(context, phrase_type=None, language=None):
    """
    for using this template tag you must
    enable one of text_phrase context_processors.
    this templatetag will return list of text phrases
    that have this phrase_type.
    if you want single text phrase in special language set the language arg.
    """
    phrases = context.get('text_phrases', None)
    if not phrases:
        raise Exception(
            "for using single_text_phrase templatetag, "
            "Please Enable one of the Text Phrase Context Processors"
        )
    if not language:
        return phrases.filter(phrase_type=phrase_type)
    return phrases.filter(phrase_type=phrase_type, language=language)



from django import template

from .nodes import FacebookShareLinkCreatorNode, TwitterShareLinkCreatorNode

register = template.Library()


@register.tag(name="facebook_share")
def generate_facebook_share_link(parser, token):
    try:
        tag_name, title, link = token.split_contents()
    except ValueError:
        raise template.TemplateSyntaxError(
            "%r tag requires two argument" % token.contents.split()[0]
        )
    return FacebookShareLinkCreatorNode(link, title)


@register.tag(name="twitter_share")
def generate_twitter_share_link(parser, token):
    try:
        tag_name, text, link, hashtags = token.split_contents()
    except ValueError:
        raise template.TemplateSyntaxError(
            "%r tag requires two argument" % token.contents.split()[0]
        )
    return TwitterShareLinkCreatorNode(text, link, hashtags)



from django.conf import settings

HANDYTOOLS_MODELS = getattr(settings, "HANDYTOOLS_MODELS", [])

TEXT_PHRASE_MODEL_PHRASE_TYPES = getattr(
    settings, "TEXT_PHRASE_MODEL_PHRASES_TYPES", [])

TEXT_IMAGE_PHRASE_MODEL_POSITIONS = getattr(
    settings, "TEXT_IMAGE_PHRASE_MODEL_POSITIONS", [])

TEXT_PHRASE_SIMPLE_CONTEXT_OBJECT_NAME = getattr(
    settings, "TEXT_PHRASE_SIMPLE_CONTEXT_OBJECT_NAME", "text_phrases")

TEXT_PHRASE_LANG_CONTEXT_OBJECT_NAME = getattr(
    settings, "TEXT_PHRASE_LANG_CONTEXT_OBJECT_NAME", "text_phrases_lang")


def _get_languages():
    """
    generate language list with Global Key
    for language independent phrases
    """
    language_list = [
        ("global", 'Global')
    ]
    for item in getattr(settings, "LANGUAGES", []):
        language_list.append(item)
    return language_list


TEXT_PHRASE_LANGUAGES = _get_languages



from django.db import models
from django.utils.translation import ugettext_lazy as _
from phonenumber_field.modelfields import PhoneNumberField


class ContactAbstractModel(models.Model):
    """
    if you don't like contact model
    inherite from this abstract models and overwrite it
    """
    name = models.CharField(verbose_name=_("Name"), max_length=255)
    email = models.EmailField(verbose_name=_("Email"), max_length=255)
    phone = PhoneNumberField(verbose_name=_("Phone"), null=False, blank=False)
    message = models.TextField(verbose_name=_("Message"))

    def __str__(self):
        return self.email

    def __unicode__(self):
        return u'%s' % self.email

    class Meta:
        abstract = True
        verbose_name = _('Contact')
        verbose_name_plural = _('Contacts')


class Contact(ContactAbstractModel):
    """ Contact Model """



# Generated by Django 2.2.1 on 2019-05-13 16:54

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='TextPhrase',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(blank=True, max_length=255, null=True, verbose_name='Title')),
                ('phrase_type', models.CharField(db_index=True, max_length=255, verbose_name='Phrase Type')),
                ('text', models.TextField(verbose_name='Text')),
                ('language', models.CharField(default='global', max_length=6, verbose_name='Language')),
            ],
            options={
                'verbose_name': 'Text Phrase',
                'verbose_name_plural': 'Text Phrases',
                'ordering': ('phrase_type',),
                'abstract': False,
            },
        ),
    ]



# Generated by Django 2.2.1 on 2019-05-14 07:33

import ckeditor_uploader.fields
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import filer.fields.image


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.FILER_IMAGE_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='TextImagePhrase',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=255, verbose_name='Title')),
                ('text', ckeditor_uploader.fields.RichTextUploadingField(verbose_name='Text')),
                ('position', models.CharField(max_length=255, verbose_name='Location')),
                ('image', filer.fields.image.FilerImageField(on_delete=django.db.models.deletion.CASCADE, to=settings.FILER_IMAGE_MODEL, verbose_name='Image')),
            ],
            options={
                'verbose_name': 'Text & Image Phrase',
                'verbose_name_plural': 'Text & Image Phrases',
                'abstract': False,
            },
        ),
    ]



from django.contrib import admin

from .models import Contact


class ContactAdminPanel(admin.ModelAdmin):
    """ i disable add permission because of security issues """
    list_display = ['name', 'email', 'phone']
    search_fields = ['name', 'email', 'phone']
    readonly_fields = ['name', 'email', 'phone', 'message']

    def has_add_permission(self, request):
        return False

    def has_change_permission(self, request, obj=None):
        return False


admin.site.register(Contact, ContactAdminPanel)



from django.contrib import admin

from .forms import TextPhraseForm
from .models import TextPhrase


class TextPhraseAdminPanel(admin.ModelAdmin):
    list_display = ['title', 'phrase_type', 'text']
    search_fields = ['title', 'phrase_type', 'text']
    form = TextPhraseForm


admin.site.register(TextPhrase, TextPhraseAdminPanel)



# -*- coding: utf-8 -*-
from __future__ import absolute_import, unicode_literals

import os

from setuptools import find_packages, setup

version = __import__('handytools').__version__

here = os.path.abspath(os.path.dirname(__file__))
README = open(os.path.join(here, 'README.md')).read()

setup(
    name='django-handytools',
    version=version,
    python_requires='>=3.6',
    packages=find_packages(exclude=["*.tests", "*.tests.*", "tests.*", "tests", "test_project"]),
    platforms=['OS Independent'],
    include_package_data=True,
    description='A Handy Tools For Your Django Project, provided tools: models, utils, context processors, templates, template tags',
    long_description=README,
    long_description_content_type='text/markdown',
    author='Mohammad Katoozi',
    author_email='k2527806@gmail.com',
    url='https://github.com/katoozi/django-handytools/',
    license='MIT',
    zip_safe=False,
    install_requires=[
        'Django>=1.11,<2.2',
        "django-ckeditor>=5.4.0",
        "django-filer>=1.3.2",
        "django-mathfilters>=0.4.0",
        "phonenumbers>=8.10.10",
        "django-easy-select2>=1.5.2",
        "django-phonenumber-field>=2.3.1"
    ],
    classifiers=[
        'Environment :: Web Environment',
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Framework :: Django',
        'Framework :: Django :: 1.11',
        'Framework :: Django :: 2.2',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
)



from django.db import models
from django.utils.translation import gettext_lazy as _


class TextPhraseAbstractModel(models.Model):
    """
    this is TextPhrase Abstract Model
    if you don't like fields or style of TextPhrase Model you can
    inheritance from this abstract model and overwrite it
    """
    title = models.CharField(
        null=True,
        blank=True,
        max_length=255,
        verbose_name=_('Title')
    )
    phrase_type = models.CharField(
        db_index=True,
        max_length=255,
        verbose_name=_('Phrase Type')
    )
    text = models.TextField(
        verbose_name=_('Text')
    )
    language = models.CharField(
        default="global", max_length=6,
        verbose_name=_('Language')
    )

    def __str__(self):
        """
        return title by default.
        if title is null or empty phrase_type will be returned.
        """
        return self.title or self.phrase_type

    def __unicode__(self):
        return u'%s' % (self.title or self.phrase_type)

    class Meta:
        abstract = True
        ordering = ('phrase_type',)
        verbose_name = _('Text Phrase')
        verbose_name_plural = _('Text Phrases')


class TextPhrase(TextPhraseAbstractModel):
    """
    this model will implement TextPhraseAbstractModel.
    if you don't like style or fields you can import
    TextPhraseAbstractModel and overwrite this model,
    and then delete TextPhraseModel from settings.py.
    use this model for phrases that have text in it, not images
    like email, phone, location, copyright note, releated links,
    social network links, languages.
    text field length is limited to 2000 character
    you can add multiple text phrase with the same phrase type.
    example:
        title : phrase_type : text
        --------------------------
        copyright    : copyright    : 2018
        AboutUsFr    : aboutus      : AboutUs
        facebook url : facebook_url : https://facebook.com
    """



from django import template
from django.template.defaultfilters import urlencode


class FacebookShareLinkCreatorNode(template.Node):
    url = "https://www.facebook.com/sharer/sharer.php?u=%s&t=%s"

    def __init__(self, link, title):
        self.link = link[1:-1]
        self.title = title[1:-1]

    def render(self, context):
        return self.url % (
            urlencode(self.link),
            urlencode(self.title)
        )


class TwitterShareLinkCreatorNode(template.Node):
    url = "https://twitter.com/share?text=%s&url=%s&hashtags=%s"

    def __init__(self, text, link, hashtags):
        self.text = text[1:-1]
        self.link = link[1:-1]
        self.hashtags = hashtags[1:-1]

    def render(self, context):
        return self.url % (
            urlencode(self.text),
            urlencode(self.link),
            self.hashtags
        )



"""
for using those context processors you must add the TextPhrase Model
in HANDYTOOLS_MODELS tuple in you settings.py
"""
from handytools.settings import (TEXT_PHRASE_LANG_CONTEXT_OBJECT_NAME,
                                 TEXT_PHRASE_SIMPLE_CONTEXT_OBJECT_NAME,)
from handytools.textphrase.models import TextPhrase


def text_phrase_simple_cp(request):
    """ this context processor will return all text phrases """
    text_phrases = TextPhrase.objects.all()
    return {
        TEXT_PHRASE_SIMPLE_CONTEXT_OBJECT_NAME: text_phrases
    }


def text_phrase_language_cp(request):
    """
    this context processor will filter text phrase base on current language
    if localization is enabled in yor project and you have
    text phrases for different locales
    it's good idea to use this context processor
    """
    text_phrases = TextPhrase.objects.filter(language=request.LANGUAGE_CODE)
    return {
        TEXT_PHRASE_LANG_CONTEXT_OBJECT_NAME: text_phrases
    }



# Generated by Django 2.2.1 on 2019-05-14 11:38

from django.db import migrations, models
import phonenumber_field.modelfields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Contact',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, verbose_name='Name')),
                ('email', models.EmailField(max_length=255, verbose_name='Email')),
                ('phone', phonenumber_field.modelfields.PhoneNumberField(max_length=128, region=None, verbose_name='Phone')),
                ('message', models.TextField(verbose_name='Message')),
            ],
            options={
                'verbose_name': 'Contact',
                'verbose_name_plural': 'Contacts',
                'abstract': False,
            },
        ),
    ]



from django.apps import AppConfig
from django.utils.translation import ugettext_lazy as _


class TextImagePhraseConfig(AppConfig):
    name = 'handytools.textimagephrase'
    verbose_name = _('Text Image Phrase App')
